@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "combinedincidenceeditor.h"
@@ -28,7 +15,6 @@ using namespace IncidenceEditorNG;
 
 CombinedIncidenceEditor::CombinedIncidenceEditor(QWidget *parent)
     : IncidenceEditor(parent)
-    , mDirtyEditorCount(0)
 {
 }
 
@@ -41,8 +27,7 @@ void CombinedIncidenceEditor::combine(IncidenceEditor *other)
 {
     Q_ASSERT(other);
     mCombinedEditors.append(other);
-    connect(other, &IncidenceEditor::dirtyStatusChanged,
-            this, &CombinedIncidenceEditor::handleDirtyStatusChange);
+    connect(other, &IncidenceEditor::dirtyStatusChanged, this, &CombinedIncidenceEditor::handleDirtyStatusChange);
 }
 
 bool CombinedIncidenceEditor::isDirty() const
@@ -52,7 +37,7 @@ bool CombinedIncidenceEditor::isDirty() const
 
 bool CombinedIncidenceEditor::isValid() const
 {
-    for (IncidenceEditor *editor : qAsConst(mCombinedEditors)) {
+    for (IncidenceEditor *editor : std::as_const(mCombinedEditors)) {
         if (!editor->isValid()) {
             const QString reason = editor->lastErrorString();
             editor->focusInvalidField();
@@ -91,7 +76,7 @@ void CombinedIncidenceEditor::handleDirtyStatusChange(bool isDirty)
 void CombinedIncidenceEditor::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
     mLoadedIncidence = incidence;
-    for (IncidenceEditor *editor : qAsConst(mCombinedEditors)) {
+    for (IncidenceEditor *editor : std::as_const(mCombinedEditors)) {
         // load() may fire dirtyStatusChanged(), reset mDirtyEditorCount to make sure
         // we don't end up with an invalid dirty count.
         editor->blockSignals(true);
@@ -101,8 +86,7 @@ void CombinedIncidenceEditor::load(const KCalendarCore::Incidence::Ptr &incidenc
         if (editor->isDirty()) {
             // We are going to crash due to assert. Print some useful info before crashing.
             qCWarning(INCIDENCEEDITOR_LOG) << "Faulty editor was " << editor->objectName();
-            qCWarning(INCIDENCEEDITOR_LOG) << "Incidence "
-                                           << (incidence ? incidence->uid() : QStringLiteral("null"));
+            qCWarning(INCIDENCEEDITOR_LOG) << "Incidence " << (incidence ? incidence->uid() : QStringLiteral("null"));
 
             editor->printDebugInfo();
 
@@ -117,7 +101,7 @@ void CombinedIncidenceEditor::load(const KCalendarCore::Incidence::Ptr &incidenc
 
 void CombinedIncidenceEditor::load(const Akonadi::Item &item)
 {
-    for (IncidenceEditor *editor : qAsConst(mCombinedEditors)) {
+    for (IncidenceEditor *editor : std::as_const(mCombinedEditors)) {
         // load() may fire dirtyStatusChanged(), reset mDirtyEditorCount to make sure
         // we don't end up with an invalid dirty count.
         editor->blockSignals(true);
@@ -142,14 +126,14 @@ void CombinedIncidenceEditor::load(const Akonadi::Item &item)
 
 void CombinedIncidenceEditor::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    for (IncidenceEditor *editor : qAsConst(mCombinedEditors)) {
+    for (IncidenceEditor *editor : std::as_const(mCombinedEditors)) {
         editor->save(incidence);
     }
 }
 
 void CombinedIncidenceEditor::save(Akonadi::Item &item)
 {
-    for (IncidenceEditor *editor : qAsConst(mCombinedEditors)) {
+    for (IncidenceEditor *editor : std::as_const(mCombinedEditors)) {
         editor->save(item);
     }
 }
