@@ -1,28 +1,15 @@
 /*
-  Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-  Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+  SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "freebusyganttproxymodel.h"
-#include "CalendarSupport/FreeBusyItemModel"
+#include <CalendarSupport/FreeBusyItemModel>
 
-#include <KGantt/KGanttGraphicsView>
 #include <KCalendarCore/FreeBusyPeriod>
+#include <KGanttGraphicsView>
 
 #include <KLocalizedString>
 
@@ -38,7 +25,7 @@ FreeBusyGanttProxyModel::FreeBusyGanttProxyModel(QObject *parent)
 QVariant FreeBusyGanttProxyModel::data(const QModelIndex &index, int role) const
 {
     if (!index.isValid()) {
-        return QVariant();
+        return {};
     }
     QModelIndex source_index = mapToSource(index);
 
@@ -50,14 +37,12 @@ QVariant FreeBusyGanttProxyModel::data(const QModelIndex &index, int role) const
         case Qt::DisplayRole:
             return source_index.data(Qt::DisplayRole);
         default:
-            return QVariant();
+            return {};
         }
     }
 
     // if the index is valid, then it corresponds to a free busy period
-    KCalendarCore::FreeBusyPeriod period
-        = sourceModel()->data(source_index, CalendarSupport::FreeBusyItemModel::FreeBusyPeriodRole).
-          value<KCalendarCore::FreeBusyPeriod>();
+    auto period = sourceModel()->data(source_index, CalendarSupport::FreeBusyItemModel::FreeBusyPeriodRole).value<KCalendarCore::FreeBusyPeriod>();
 
     switch (role) {
     case KGantt::ItemTypeRole:
@@ -73,38 +58,29 @@ QVariant FreeBusyGanttProxyModel::data(const QModelIndex &index, int role) const
     case Qt::DisplayRole:
         return sourceModel()->data(source_index.parent(), Qt::DisplayRole);
     default:
-        return QVariant();
+        return {};
     }
 }
 
 QString FreeBusyGanttProxyModel::tooltipify(const KCalendarCore::FreeBusyPeriod &period) const
 {
     QString toolTip = QStringLiteral("<qt>");
-    toolTip += QLatin1String("<b>") + i18nc("@info:tooltip", "Free/Busy Period") + QLatin1String(
-        "</b>");
+    toolTip += QLatin1String("<b>") + i18nc("@info:tooltip", "Free/Busy Period") + QLatin1String("</b>");
     toolTip += QStringLiteral("<hr>");
     if (!period.summary().isEmpty()) {
-        toolTip += QLatin1String("<i>") + i18nc("@info:tooltip", "Summary:") + QLatin1String(
-            "</i>") + QStringLiteral("&nbsp;");
+        toolTip += QLatin1String("<i>") + i18nc("@info:tooltip", "Summary:") + QLatin1String("</i>") + QStringLiteral("&nbsp;");
         toolTip += period.summary();
         toolTip += QStringLiteral("<br>");
     }
     if (!period.location().isEmpty()) {
-        toolTip += QLatin1String("<i>") + i18nc("@info:tooltip", "Location:") + QLatin1String(
-            "</i>") + QStringLiteral("&nbsp;");
+        toolTip += QLatin1String("<i>") + i18nc("@info:tooltip", "Location:") + QLatin1String("</i>") + QStringLiteral("&nbsp;");
         toolTip += period.location();
         toolTip += QStringLiteral("<br>");
     }
-    toolTip += QStringLiteral("<i>")
-               + i18nc("@info:tooltip period start time",
-                       "Start:") + QStringLiteral("</i>") + QStringLiteral(
-        "&nbsp;");
+    toolTip += QStringLiteral("<i>") + i18nc("@info:tooltip period start time", "Start:") + QStringLiteral("</i>") + QStringLiteral("&nbsp;");
     toolTip += QLocale().toString(period.start().toLocalTime(), QLocale::ShortFormat);
     toolTip += QStringLiteral("<br>");
-    toolTip += QStringLiteral("<i>")
-               + i18nc("@info:tooltip period end time",
-                       "End:") + QStringLiteral("</i>") + QStringLiteral(
-        "&nbsp;");
+    toolTip += QStringLiteral("<i>") + i18nc("@info:tooltip period end time", "End:") + QStringLiteral("</i>") + QStringLiteral("&nbsp;");
     toolTip += QLocale().toString(period.end().toLocalTime(), QLocale::ShortFormat);
     toolTip += QStringLiteral("<br>");
     toolTip += QStringLiteral("</qt>");
