@@ -19,6 +19,7 @@
 #include <KActionCollection>
 #include <KIO/Job>
 #include <KIO/JobUiDelegate>
+#include <KIO/JobUiDelegateFactory>
 #include <KIO/OpenUrlJob>
 #include <KIO/StoredTransferJob>
 #include <KJobWidgets>
@@ -35,6 +36,7 @@
 #include <QMimeData>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <kwidgetsaddons_version.h>
 
 using namespace IncidenceEditorNG;
 
@@ -187,13 +189,22 @@ void IncidenceAttachment::removeSelectedAttachments()
 
     QString labelsStr = labels.join(QLatin1String("<nl/>"));
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (KMessageBox::questionTwoActions(nullptr,
+#else
     if (KMessageBox::questionYesNo(nullptr,
-                                   xi18nc("@info", "Do you really want to remove these attachments?<nl/>%1", labelsStr),
-                                   i18nc("@title:window", "Remove Attachments?"),
-                                   KStandardGuiItem::remove(),
-                                   KStandardGuiItem::cancel(),
-                                   QStringLiteral("calendarRemoveAttachments"))
+
+#endif
+                                        xi18nc("@info", "Do you really want to remove these attachments?<nl/>%1", labelsStr),
+                                        i18nc("@title:window", "Remove Attachments?"),
+                                        KStandardGuiItem::remove(),
+                                        KStandardGuiItem::cancel(),
+                                        QStringLiteral("calendarRemoveAttachments"))
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        != KMessageBox::ButtonCode::PrimaryAction) {
+#else
         != KMessageBox::Yes) {
+#endif
         return;
     }
 
@@ -270,13 +281,13 @@ void IncidenceAttachment::showAttachment(QListWidgetItem *item)
         openURL(QUrl(att.uri()));
     } else {
         auto job = new KIO::OpenUrlJob(attitem->tempFileForAttachment(), att.mimeType());
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mAttachmentView));
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mAttachmentView));
         job->setDeleteTemporaryFile(true);
         job->start();
     }
 }
 
-void IncidenceAttachment::showContextMenu(const QPoint &pos)    // clazy:exclude=function-args-by-value
+void IncidenceAttachment::showContextMenu(const QPoint &pos) // clazy:exclude=function-args-by-value
 {
     const bool enable = mAttachmentView->itemAt(pos) != nullptr;
 
@@ -524,6 +535,7 @@ void IncidenceAttachment::setupAttachmentIconView()
     auto layout = new QGridLayout(mUi->mAttachmentViewPlaceHolder);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(mAttachmentView);
+    QWidget::setTabOrder(mUi->mAddButton, mAttachmentView);
 }
 
 // void IncidenceAttachmentEditor::addAttachment( KCalendarCore::Attachment *attachment )
