@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencedescription.h"
@@ -24,21 +11,20 @@
 
 #include "incidenceeditor_debug.h"
 #include <KActionCollection>
-#include <KToolBar>
 #include <KLocalizedString>
+#include <KToolBar>
 
 using namespace IncidenceEditorNG;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class IncidenceDescriptionPrivate
 {
 public:
-    IncidenceDescriptionPrivate() : mRichTextEnabled(false)
-    {
-    }
+    IncidenceDescriptionPrivate() = default;
 
     QString mRealOriginalDescriptionEditContents;
-    bool mRichTextEnabled;
+    bool mRichTextEnabled = false;
 };
 }
 
@@ -50,17 +36,11 @@ IncidenceDescription::IncidenceDescription(Ui::EventOrTodoDesktop *ui)
     setObjectName(QStringLiteral("IncidenceDescription"));
     mUi->mRichTextLabel->setContextMenuPolicy(Qt::NoContextMenu);
     setupToolBar();
-    connect(mUi->mRichTextLabel, &QLabel::linkActivated, this,
-            &IncidenceDescription::toggleRichTextDescription);
-    connect(
-        mUi->mDescriptionEdit->richTextComposer(), &KPIMTextEdit::RichTextComposer::textChanged, this,
-        &IncidenceDescription::checkDirtyStatus);
+    connect(mUi->mRichTextLabel, &QLabel::linkActivated, this, &IncidenceDescription::toggleRichTextDescription);
+    connect(mUi->mDescriptionEdit->richTextComposer(), &KPIMTextEdit::RichTextComposer::textChanged, this, &IncidenceDescription::checkDirtyStatus);
 }
 
-IncidenceDescription::~IncidenceDescription()
-{
-    delete d;
-}
+IncidenceDescription::~IncidenceDescription() = default;
 
 void IncidenceDescription::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
@@ -72,12 +52,10 @@ void IncidenceDescription::load(const KCalendarCore::Incidence::Ptr &incidence)
         enableRichTextDescription(incidence->descriptionIsRich());
         if (incidence->descriptionIsRich()) {
             mUi->mDescriptionEdit->richTextComposer()->setHtml(incidence->richDescription());
-            d->mRealOriginalDescriptionEditContents
-                = mUi->mDescriptionEdit->richTextComposer()->toHtml();
+            d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toHtml();
         } else {
             mUi->mDescriptionEdit->richTextComposer()->setPlainText(incidence->description());
-            d->mRealOriginalDescriptionEditContents
-                = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
+            d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
         }
     } else {
         enableRichTextDescription(false);
@@ -108,13 +86,9 @@ bool IncidenceDescription::isDirty() const
        any transformation regarding non-printable chars will be irrelevant.
     */
     if (d->mRichTextEnabled) {
-        return !mLoadedIncidence->descriptionIsRich()
-               || d->mRealOriginalDescriptionEditContents
-               != mUi->mDescriptionEdit->richTextComposer()->toHtml();
+        return !mLoadedIncidence->descriptionIsRich() || d->mRealOriginalDescriptionEditContents != mUi->mDescriptionEdit->richTextComposer()->toHtml();
     } else {
-        return mLoadedIncidence->descriptionIsRich()
-               || d->mRealOriginalDescriptionEditContents
-               != mUi->mDescriptionEdit->richTextComposer()->toPlainText();
+        return mLoadedIncidence->descriptionIsRich() || d->mRealOriginalDescriptionEditContents != mUi->mDescriptionEdit->richTextComposer()->toPlainText();
     }
 }
 
@@ -129,12 +103,10 @@ void IncidenceDescription::enableRichTextDescription(bool enable)
         rt = i18nc("@action Enable or disable rich text editing", "Disable rich text");
         placeholder = QStringLiteral("<a href=\"show\">&lt;&lt; %1</a>");
         mUi->mDescriptionEdit->richTextComposer()->activateRichText();
-        d->mRealOriginalDescriptionEditContents
-            = mUi->mDescriptionEdit->richTextComposer()->toHtml();
+        d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toHtml();
     } else {
         mUi->mDescriptionEdit->richTextComposer()->switchToPlainText();
-        d->mRealOriginalDescriptionEditContents
-            = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
+        d->mRealOriginalDescriptionEditContents = mUi->mDescriptionEdit->richTextComposer()->toPlainText();
     }
 
     placeholder = placeholder.arg(rt);
@@ -152,10 +124,10 @@ void IncidenceDescription::toggleRichTextDescription()
 void IncidenceDescription::setupToolBar()
 {
 #ifndef QT_NO_TOOLBAR
-    KActionCollection *collection = new KActionCollection(this);
+    auto collection = new KActionCollection(this);
     mUi->mDescriptionEdit->richTextComposer()->createActions(collection);
 
-    KToolBar *mEditToolBar = new KToolBar(mUi->mEditToolBarPlaceHolder);
+    auto mEditToolBar = new KToolBar(mUi->mEditToolBarPlaceHolder);
     mEditToolBar->setToolButtonStyle(Qt::ToolButtonIconOnly);
     mEditToolBar->addAction(collection->action(QStringLiteral("format_text_bold")));
     mEditToolBar->addAction(collection->action(QStringLiteral("format_text_italic")));
@@ -185,7 +157,7 @@ void IncidenceDescription::setupToolBar()
     mEditToolBar->addAction(collection->action(QStringLiteral("manage_link")));
     mUi->mDescriptionEdit->richTextComposer()->setEnableActions(false);
 
-    QGridLayout *layout = new QGridLayout(mUi->mEditToolBarPlaceHolder);
+    auto layout = new QGridLayout(mUi->mEditToolBarPlaceHolder);
     layout->addWidget(mEditToolBar);
 #endif
 
@@ -200,31 +172,18 @@ void IncidenceDescription::printDebugInfo() const
     qCDebug(INCIDENCEEDITOR_LOG) << "RichText enabled " << d->mRichTextEnabled;
 
     if (mLoadedIncidence) {
-        qCDebug(INCIDENCEEDITOR_LOG) << "Incidence description is rich "
-                                     << mLoadedIncidence->descriptionIsRich();
+        qCDebug(INCIDENCEEDITOR_LOG) << "Incidence description is rich " << mLoadedIncidence->descriptionIsRich();
 
         if (mLoadedIncidence->descriptionIsRich()) {
-            qCDebug(INCIDENCEEDITOR_LOG) << "desc is rich, and it is <desc>"
-                                         <<  mLoadedIncidence->richDescription()
-                                         << "</desc>; "
-                                         << "widget has <desc>"
-                                         << mUi->mDescriptionEdit->richTextComposer()->toHtml()
-                                         << "</desc>; "
-                                         <<
-                "expr mLoadedIncidence->richDescription() != mUi->mDescriptionEdit->toHtml() is "
-                                         << (mLoadedIncidence->richDescription()
-                != mUi->mDescriptionEdit->richTextComposer()->toHtml());
+            qCDebug(INCIDENCEEDITOR_LOG) << "desc is rich, and it is <desc>" << mLoadedIncidence->richDescription() << "</desc>; "
+                                         << "widget has <desc>" << mUi->mDescriptionEdit->richTextComposer()->toHtml() << "</desc>; "
+                                         << "expr mLoadedIncidence->richDescription() != mUi->mDescriptionEdit->toHtml() is "
+                                         << (mLoadedIncidence->richDescription() != mUi->mDescriptionEdit->richTextComposer()->toHtml());
         } else {
-            qCDebug(INCIDENCEEDITOR_LOG) << "desc is not rich, and it is <desc>"
-                                         << mLoadedIncidence->description()
-                                         << "</desc>; "
-                                         << "widget has <desc>"
-                                         << mUi->mDescriptionEdit->richTextComposer()->toPlainText()
-                                         << "</desc>; "
-                                         <<
-                "expr mLoadedIncidence->description() != mUi->mDescriptionEdit->toPlainText() is "
-                                         << (mLoadedIncidence->description()
-                != mUi->mDescriptionEdit->richTextComposer()->toPlainText());
+            qCDebug(INCIDENCEEDITOR_LOG) << "desc is not rich, and it is <desc>" << mLoadedIncidence->description() << "</desc>; "
+                                         << "widget has <desc>" << mUi->mDescriptionEdit->richTextComposer()->toPlainText() << "</desc>; "
+                                         << "expr mLoadedIncidence->description() != mUi->mDescriptionEdit->toPlainText() is "
+                                         << (mLoadedIncidence->description() != mUi->mDescriptionEdit->richTextComposer()->toPlainText());
         }
     } else {
         qCDebug(INCIDENCEEDITOR_LOG) << "Incidence is invalid";
