@@ -1,53 +1,45 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_INCIDENCEDIALOG_H
-#define INCIDENCEEDITOR_INCIDENCEDIALOG_H
+#pragma once
 
-#include "incidenceeditor_export.h"
 #include "editoritemmanager.h"
+#include "incidenceeditor_export.h"
 
 #include <QDate>
 #include <QDialog>
 
+#include <memory>
+
 class QAbstractButton;
 
-namespace Akonadi {
+namespace Akonadi
+{
 class IncidenceChanger;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class IncidenceDialogPrivate;
-
+/**
+ * @brief The IncidenceDialog class
+ */
 class INCIDENCEEDITOR_EXPORT IncidenceDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit IncidenceDialog(Akonadi::IncidenceChanger *changer = nullptr, QWidget *parent = nullptr, Qt::WindowFlags flags = {});
-    ~IncidenceDialog();
+    ~IncidenceDialog() override;
 
     /**
      * Loads the @param item into the dialog.
      *
      * To create a new Incidence pass an invalid item with either an
-     * KCalCore::Event:Ptr or a KCalCore::Todo:Ptr set as payload. Note: When the
+     * KCalendarCore::Event:Ptr or a KCalendarCore::Todo:Ptr set as payload. Note: When the
      * item is invalid, i.e. it has an invalid id, a valid payload <em>must</em>
      * be set.
      *
@@ -88,38 +80,21 @@ Q_SIGNALS:
      */
     void incidenceCreated(const Akonadi::Item &);
     void invalidCollection() const;
+
 protected:
     void closeEvent(QCloseEvent *event) override;
 
 protected Q_SLOTS:
     void slotButtonClicked(QAbstractButton *button);
     void handleSelectedCollectionChange(const Akonadi::Collection &collection);
+    void reject() override;
 
 private:
-    IncidenceDialogPrivate *const d_ptr;
+    std::unique_ptr<IncidenceDialogPrivate> const d_ptr;
     Q_DECLARE_PRIVATE(IncidenceDialog)
     Q_DISABLE_COPY(IncidenceDialog)
 
     void writeConfig();
     void readConfig();
-
-    Q_PRIVATE_SLOT(d_ptr, void handleAlarmCountChange(int))
-    Q_PRIVATE_SLOT(d_ptr, void handleItemSaveFinish(
-                       IncidenceEditorNG::EditorItemManager::SaveAction))
-    Q_PRIVATE_SLOT(d_ptr,
-                   void handleItemSaveFail(IncidenceEditorNG::EditorItemManager::SaveAction,
-                                           QString))
-    Q_PRIVATE_SLOT(d_ptr, void handleRecurrenceChange(IncidenceEditorNG::RecurrenceType))
-    Q_PRIVATE_SLOT(d_ptr, void loadTemplate(QString))
-    Q_PRIVATE_SLOT(d_ptr, void saveTemplate(QString))
-    Q_PRIVATE_SLOT(d_ptr, void storeTemplatesInConfig(QStringList))
-    Q_PRIVATE_SLOT(d_ptr, void updateAttachmentCount(int))
-    Q_PRIVATE_SLOT(d_ptr, void updateAttendeeCount(int))
-    Q_PRIVATE_SLOT(d_ptr, void updateResourceCount(int))
-    Q_PRIVATE_SLOT(d_ptr, void updateButtonStatus(bool))
-    Q_PRIVATE_SLOT(d_ptr, void showMessage(QString, KMessageWidget::MessageType))
-    Q_PRIVATE_SLOT(d_ptr, void slotInvalidCollection())
 };
 }
-
-#endif
