@@ -1,21 +1,8 @@
 /*
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencewhatwhere.h"
@@ -31,10 +18,8 @@ IncidenceWhatWhere::IncidenceWhatWhere(Ui::EventOrTodoDesktop *ui)
     , mUi(ui)
 {
     setObjectName(QStringLiteral("IncidenceWhatWhere"));
-    connect(mUi->mSummaryEdit, &QLineEdit::textChanged, this,
-            &IncidenceWhatWhere::checkDirtyStatus);
-    connect(mUi->mLocationEdit, &QLineEdit::textChanged, this,
-            &IncidenceWhatWhere::checkDirtyStatus);
+    connect(mUi->mSummaryEdit, &QLineEdit::textChanged, this, &IncidenceWhatWhere::checkDirtyStatus);
+    connect(mUi->mLocationEdit, &QLineEdit::textChanged, this, &IncidenceWhatWhere::checkDirtyStatus);
 }
 
 void IncidenceWhatWhere::load(const KCalendarCore::Incidence::Ptr &incidence)
@@ -65,21 +50,24 @@ void IncidenceWhatWhere::save(const KCalendarCore::Incidence::Ptr &incidence)
 bool IncidenceWhatWhere::isDirty() const
 {
     if (mLoadedIncidence) {
-        return
-            (mUi->mSummaryEdit->text() != mLoadedIncidence->summary())
-            || (mUi->mLocationEdit->text() != mLoadedIncidence->location());
+        return (mUi->mSummaryEdit->text() != mLoadedIncidence->summary()) || (mUi->mLocationEdit->text() != mLoadedIncidence->location());
     } else {
-        return
-            mUi->mSummaryEdit->text().isEmpty()
-            && mUi->mLocationEdit->text().isEmpty();
+        return mUi->mSummaryEdit->text().isEmpty() && mUi->mLocationEdit->text().isEmpty();
+    }
+}
+
+void IncidenceWhatWhere::focusInvalidField()
+{
+    if (mUi->mSummaryEdit->text().isEmpty()) {
+        mUi->mSummaryEdit->setFocus();
     }
 }
 
 bool IncidenceWhatWhere::isValid() const
 {
     if (mUi->mSummaryEdit->text().isEmpty()) {
-        qCDebug(INCIDENCEEDITOR_LOG) << "Specify a title";
-        mLastErrorString = i18nc("@info", "Please specify a title.");
+        qCDebug(INCIDENCEEDITOR_LOG) << "Specify a summary";
+        mLastErrorString = i18nc("@info", "Please enter a summary.");
         return false;
     } else {
         mLastErrorString.clear();
