@@ -1,23 +1,7 @@
 /*
- * Copyright (c) 2014 Sandro Knauß <knauss@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Sandro Knauß <knauss@kolabsys.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * As a special exception, permission is given to link this program
- * with any edition of Qt, and distribute the resulting executable,
- * without including the source code for Qt in the source distribution.
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
 #include "individualmailcomponentfactory.h"
@@ -27,6 +11,7 @@
 #include <CalendarSupport/KCalPrefs>
 
 #include <KMessageBox>
+#include <kwidgetsaddons_version.h>
 
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
@@ -35,30 +20,27 @@ using namespace IncidenceEditorNG;
 
 // IndividualMessageQueueJob
 
-IndividualMessageQueueJob::IndividualMessageQueueJob(const KIdentityManagement::Identity &identity, const KCalendarCore::Attendee::List &update, const KCalendarCore::Attendee::List &edit, QObject *parent)
+IndividualMessageQueueJob::IndividualMessageQueueJob(const KIdentityManagement::Identity &identity,
+                                                     const KCalendarCore::Attendee::List &update,
+                                                     const KCalendarCore::Attendee::List &edit,
+                                                     QObject *parent)
     : MailTransport::MessageQueueJob(parent)
     , mUpdate(update)
     , mEdit(edit)
     , mIdentity(identity)
-    , mQueueJob(nullptr)
-    , mComposerJob(nullptr)
 {
 }
 
 void IndividualMessageQueueJob::start()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     const auto to = addressAttribute().to();
     QSet<QString> attendeesTo(to.begin(), to.end());
     const auto cc = addressAttribute().cc();
     QSet<QString> attendeesCc(cc.begin(), cc.end());
-#else
-    QSet<QString> attendeesTo(QSet<QString>::fromList(addressAttribute().to()));
-    QSet<QString> attendeesCc(QSet<QString>::fromList(addressAttribute().cc()));
-#endif
 
-    QStringList attendeesAutoTo, attendeesAutoCc;
-    for (const KCalendarCore::Attendee &attendee : qAsConst(mUpdate)) {
+    QStringList attendeesAutoTo;
+    QStringList attendeesAutoCc;
+    for (const KCalendarCore::Attendee &attendee : std::as_const(mUpdate)) {
         if (attendeesTo.contains(attendee.email())) {
             attendeesAutoTo.append(attendee.fullName());
         }
@@ -66,13 +48,13 @@ void IndividualMessageQueueJob::start()
             attendeesAutoCc.append(attendee.fullName());
         }
     }
-    if (!attendeesAutoTo.isEmpty() || !attendeesAutoCc.isEmpty()
-        || !addressAttribute().bcc().isEmpty()) {
+    if (!attendeesAutoTo.isEmpty() || !attendeesAutoCc.isEmpty() || !addressAttribute().bcc().isEmpty()) {
         startQueueJob(attendeesAutoTo, addressAttribute().to(), attendeesAutoCc, addressAttribute().cc());
     }
 
-    QStringList attendeesComposerTo, attendeesComposerCc;
-    for (const KCalendarCore::Attendee &attendee : qAsConst(mEdit)) {
+    QStringList attendeesComposerTo;
+    QStringList attendeesComposerCc;
+    for (const KCalendarCore::Attendee &attendee : std::as_const(mEdit)) {
         if (attendeesTo.contains(attendee.email())) {
             attendeesComposerTo.append(attendee.fullName());
         }
@@ -113,24 +95,18 @@ void IndividualMessageQueueJob::startQueueJob(const QStringList &messageTo, cons
             mQueueJob->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::MoveToCollection);
             mQueueJob->sentBehaviourAttribute().setMoveToCollection(sentCollection);
         } else {
-            mQueueJob->sentBehaviourAttribute().setSentBehaviour(
-                MailTransport::SentBehaviourAttribute::MoveToDefaultSentCollection);
+            mQueueJob->sentBehaviourAttribute().setSentBehaviour(MailTransport::SentBehaviourAttribute::MoveToDefaultSentCollection);
         }
     }
 
-    connect(mQueueJob, &MailTransport::MessageQueueJob::finished, this,
-            &IndividualMessageQueueJob::handleJobFinished);
+    connect(mQueueJob, &MailTransport::MessageQueueJob::finished, this, &IndividualMessageQueueJob::handleJobFinished);
     mQueueJob->start();
 }
 
 void IndividualMessageQueueJob::startComposerJob(const QStringList &to, const QStringList &cc)
 {
-    mComposerJob
-        = new OpenComposerJob(this, to.join(QLatin1String(", ")), cc.join(QLatin1String(
-                                                                              ", ")),
-                              QString(), message(), mIdentity);
-    connect(mComposerJob, &OpenComposerJob::finished, this,
-            &IndividualMessageQueueJob::handleJobFinished);
+    mComposerJob = new OpenComposerJob(this, to.join(QLatin1String(", ")), cc.join(QLatin1String(", ")), QString(), message(), mIdentity);
+    connect(mComposerJob, &OpenComposerJob::finished, this, &IndividualMessageQueueJob::handleJobFinished);
     mComposerJob->start();
 }
 
@@ -164,37 +140,57 @@ void IndividualMessageQueueJob::handleJobFinished(KJob *job)
 
 // IndividualMailAskDelegator
 
-IndividualMailITIPHandlerDialogDelegate::IndividualMailITIPHandlerDialogDelegate(
-    const KCalendarCore::Incidence::Ptr &incidence, KCalendarCore::iTIPMethod method, QWidget *parent)
+IndividualMailITIPHandlerDialogDelegate::IndividualMailITIPHandlerDialogDelegate(const KCalendarCore::Incidence::Ptr &incidence,
+                                                                                 KCalendarCore::iTIPMethod method,
+                                                                                 QWidget *parent)
     : Akonadi::ITIPHandlerDialogDelegate(incidence, method, parent)
     , mDialog(nullptr)
 {
 }
 
-void IndividualMailITIPHandlerDialogDelegate::openDialog(const QString &question, const KCalendarCore::Attendee::List &attendees, Action action, const KGuiItem &buttonYes, const KGuiItem &buttonNo)
+void IndividualMailITIPHandlerDialogDelegate::openDialog(const QString &question,
+                                                         const KCalendarCore::Attendee::List &attendees,
+                                                         Action action,
+                                                         const KGuiItem &buttonYes,
+                                                         const KGuiItem &buttonNo)
 {
     switch (action) {
     case ActionSendMessage:
         Q_EMIT setUpdate(mIncidence, attendees);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::PrimaryAction, mMethod, mIncidence);
+#else
         Q_EMIT dialogClosed(KMessageBox::Yes, mMethod, mIncidence);
+#endif
         break;
     case ActionDontSendMessage:
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::SecondaryAction, mMethod, mIncidence);
+#else
         Q_EMIT dialogClosed(KMessageBox::No, mMethod, mIncidence);
+#endif
         break;
     default:
         switch (CalendarSupport::KCalPrefs::instance()->sendPolicy()) {
         case (CalendarSupport::KCalPrefs::InvitationPolicySend):
             Q_EMIT setUpdate(mIncidence, attendees);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            Q_EMIT dialogClosed(KMessageBox::ButtonCode::PrimaryAction, mMethod, mIncidence);
+#else
             Q_EMIT dialogClosed(KMessageBox::Yes, mMethod, mIncidence);
+#endif
             break;
         case (CalendarSupport::KCalPrefs::InvitationPolicyDontSend):
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            Q_EMIT dialogClosed(KMessageBox::ButtonCode::SecondaryAction, mMethod, mIncidence);
+#else
             Q_EMIT dialogClosed(KMessageBox::No, mMethod, mIncidence);
+#endif
             break;
         case (CalendarSupport::KCalPrefs::InvitationPolicyAsk):
         default:
             mDialog = new IndividualMailDialog(question, attendees, buttonYes, buttonNo, mParent);
-            connect(mDialog, &QDialog::finished, this,
-                    &IndividualMailITIPHandlerDialogDelegate::onDialogClosed);
+            connect(mDialog, &QDialog::finished, this, &IndividualMailITIPHandlerDialogDelegate::onDialogClosed);
             mDialog->show();
             break;
         }
@@ -202,7 +198,11 @@ void IndividualMailITIPHandlerDialogDelegate::openDialog(const QString &question
     }
 }
 
-void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceCreated(Recipient recipient, const QString &question, Action action, const KGuiItem &buttonYes, const KGuiItem &buttonNo)
+void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceCreated(Recipient recipient,
+                                                                         const QString &question,
+                                                                         Action action,
+                                                                         const KGuiItem &buttonYes,
+                                                                         const KGuiItem &buttonNo)
 {
     if (recipient == Attendees) {
         openDialog(question, mIncidence->attendees(), action, buttonYes, buttonNo);
@@ -212,10 +212,14 @@ void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceCreated(Recipie
     }
 }
 
-void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceModified(
-    bool attendeeStatusChanged, Recipient recipient, const QString &question, Action action, const KGuiItem &buttonYes, const KGuiItem &buttonNo)
+void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceModified(bool attendeeStatusChanged,
+                                                                          Recipient recipient,
+                                                                          const QString &question,
+                                                                          Action action,
+                                                                          const KGuiItem &buttonYes,
+                                                                          const KGuiItem &buttonNo)
 {
-    Q_UNUSED(attendeeStatusChanged);
+    Q_UNUSED(attendeeStatusChanged)
     if (recipient == Attendees) {
         openDialog(question, mIncidence->attendees(), action, buttonYes, buttonNo);
     } else {
@@ -224,7 +228,11 @@ void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceModified(
     }
 }
 
-void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceDeleted(Recipient recipient, const QString &question, Action action, const KGuiItem &buttonYes, const KGuiItem &buttonNo)
+void IndividualMailITIPHandlerDialogDelegate::openDialogIncidenceDeleted(Recipient recipient,
+                                                                         const QString &question,
+                                                                         Action action,
+                                                                         const KGuiItem &buttonYes,
+                                                                         const KGuiItem &buttonNo)
 {
     if (recipient == Attendees) {
         openDialog(question, mIncidence->attendees(), action, buttonYes, buttonNo);
@@ -239,9 +247,17 @@ void IndividualMailITIPHandlerDialogDelegate::onDialogClosed(int result)
     if (result == QDialogButtonBox::Yes) {
         Q_EMIT setEdit(mIncidence, mDialog->editAttendees());
         Q_EMIT setUpdate(mIncidence, mDialog->updateAttendees());
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::PrimaryAction, mMethod, mIncidence);
+#else
         Q_EMIT dialogClosed(KMessageBox::Yes, mMethod, mIncidence);
+#endif
     } else {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        Q_EMIT dialogClosed(KMessageBox::ButtonCode::SecondaryAction, mMethod, mIncidence);
+#else
         Q_EMIT dialogClosed(KMessageBox::No, mMethod, mIncidence);
+#endif
     }
 }
 
@@ -251,22 +267,20 @@ IndividualMailComponentFactory::IndividualMailComponentFactory(QObject *parent)
 {
 }
 
-MailTransport::MessageQueueJob *IndividualMailComponentFactory::createMessageQueueJob(
-    const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, QObject *parent)
+MailTransport::MessageQueueJob *IndividualMailComponentFactory::createMessageQueueJob(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                                                                                      const KIdentityManagement::Identity &identity,
+                                                                                      QObject *parent)
 {
-    return new IndividualMessageQueueJob(identity, mUpdate.take(incidence->uid()),
-                                         mEdit.take(incidence->uid()), parent);
+    return new IndividualMessageQueueJob(identity, mUpdate.take(incidence->uid()), mEdit.take(incidence->uid()), parent);
 }
 
-Akonadi::ITIPHandlerDialogDelegate *IndividualMailComponentFactory::createITIPHanderDialogDelegate(
-    const KCalendarCore::Incidence::Ptr &incidence, KCalendarCore::iTIPMethod method, QWidget *parent)
+Akonadi::ITIPHandlerDialogDelegate *IndividualMailComponentFactory::createITIPHanderDialogDelegate(const KCalendarCore::Incidence::Ptr &incidence,
+                                                                                                   KCalendarCore::iTIPMethod method,
+                                                                                                   QWidget *parent)
 {
-    IndividualMailITIPHandlerDialogDelegate *askDelegator
-        = new IndividualMailITIPHandlerDialogDelegate(incidence, method, parent);
-    connect(askDelegator, &IndividualMailITIPHandlerDialogDelegate::setEdit, this,
-            &IndividualMailComponentFactory::onSetEdit);
-    connect(askDelegator, &IndividualMailITIPHandlerDialogDelegate::setUpdate, this,
-            &IndividualMailComponentFactory::onSetUpdate);
+    auto askDelegator = new IndividualMailITIPHandlerDialogDelegate(incidence, method, parent);
+    connect(askDelegator, &IndividualMailITIPHandlerDialogDelegate::setEdit, this, &IndividualMailComponentFactory::onSetEdit);
+    connect(askDelegator, &IndividualMailITIPHandlerDialogDelegate::setUpdate, this, &IndividualMailComponentFactory::onSetUpdate);
 
     return askDelegator;
 }
