@@ -8,8 +8,6 @@
 
 #include "kweekdaycheckcombo.h"
 
-#include "incidenceeditor_debug.h"
-
 #include <QLocale>
 
 using namespace IncidenceEditorNG;
@@ -36,9 +34,7 @@ KWeekdayCheckCombo::KWeekdayCheckCombo(QWidget *parent, bool first5Checked)
     }
 }
 
-KWeekdayCheckCombo::~KWeekdayCheckCombo()
-{
-}
+KWeekdayCheckCombo::~KWeekdayCheckCombo() = default;
 
 QBitArray KWeekdayCheckCombo::days() const
 {
